@@ -59,7 +59,7 @@ namespace libxl
         virtual             bool XLAPIENTRY colHidden(int col) const = 0;
         virtual             bool XLAPIENTRY setColHidden(int col, bool hidden) = 0;
 
-        virtual             bool XLAPIENTRY getMerge(int row, int col, int* rowFirst, int* rowLast, int* colFirst, int* colLast) = 0;
+        virtual             bool XLAPIENTRY getMerge(int row, int col, int* rowFirst = 0, int* rowLast = 0, int* colFirst = 0, int* colLast = 0) = 0;
         virtual             bool XLAPIENTRY setMerge(int rowFirst, int rowLast, int colFirst, int colLast) = 0;
         virtual             bool XLAPIENTRY delMerge(int row, int col) = 0;
 
